pub struct CustomName(/* private fields */);Expand description
A custom name for a control.
This is a 32-byte array that can be used to store a custom name for a control.
Note
The name is trimmed to 32 bytes, so it is possible that the name is truncated.
Example
use generic_camera::controls::CustomName;
let name: CustomName = "UUID".into();
assert_eq!(name.as_str(), "UUID");
let name: CustomName = "My Custom Very Long Name".into();
assert_eq!(name.as_str(), "My Custom Very L");Implementations