GenericImage

Enum GenericImage 

pub enum GenericImage<'a> {
    Ref(GenericImageRef<'a>),
    Own(GenericImageOwned),
}
A serializable, generic image with metadata, backed by either a GenericImageRef or a GenericImageOwned.

Variants

Implementations

Source

impl GenericImage<'_>

pub fn timestamp(&self) -> DateTime<Utc>

The UTC timestamp of the image.

pub fn exposure(&self) -> Duration

The exposure time of the image (Duration::ZERO if not applicable).

pub fn set_exposure(&mut self, exposure: Duration)

Set the exposure time of the image.

pub fn frame_id(&self) -> Option<u32>

The acquisition frame ID of the image, or None if unset.

pub fn set_frame_id(&mut self, frame_id: u32)

Set the acquisition frame ID of the image.

pub fn insert_key<T>( &mut self, name: &str, value: T, ) -> Result<(), MetadataError>
where T: InsertValue,

Insert a metadata value into the GenericImage.

Arguments
  • name: The name of the metadata value. The name must be non-empty and less than 80 characters.
  • value: The value to insert. The value is either a primitive type, a String, or a std::time::Duration or a UTC chrono::DateTime or a tuple of a primitive type and a comment ().
Valid Types

The valid types for the metadata value are:

Note
  • The metadata key is case-insensitive and is stored as an uppercase string.
  • Re-inserting a timestamp key will return an error.
  • When saving to a FITS file, the metadata comment may be truncated.
  • Metadata of type std::time::Duration or a UTC chrono::DateTime is stored as two consecutive metadata items split into seconds and nanoseconds (keys suffixed _S and _NS), plus a base card.
pub fn remove_key( &mut self, name: &str, ) -> Result<GenericLineItem, MetadataError>

Remove a metadata value from the GenericImageOwned.

Arguments
  • name: The name of the metadata value to remove.
Returns
  • Ok(()) if the key was removed successfully.
  • Err("Can not remove timestamp key") if the key is the timestamp key.
  • Err("Key not found") if the key was not found.
  • Err("Key cannot be empty") if the key is an empty string.
  • Err("Key cannot be longer than 80 characters") if the key is longer than 80 characters.
pub fn replace_key<T>( &mut self, name: &str, value: T, ) -> Result<GenericLineItem, MetadataError>
where T: InsertValue,

Replace a metadata value in the GenericImageOwned.

Arguments
  • name: The name of the metadata value to replace.
  • value: The new value to insert. The value is either a primitive type, a String, or a std::time::Duration or a UTC chrono::DateTime or a tuple of a value type and a comment.
Returns
  • Ok(()) if the key was replaced successfully.
  • Err("Key not found") if the key was not found.
pub fn image(&self) -> DynamicImageView<'_>

A read-only, type-erased DynamicImageView over the samples, whichever half this GenericImage holds.

pub fn metadata(&self) -> &Metadata

Borrow the image’s Metadata.

pub fn metadata_mut(&mut self) -> &mut Metadata

Mutably borrow the image’s Metadata.

pub fn key(&self, name: &str) -> Option<&GenericLineItem>

A specific extra metadata item by name (case-insensitive).

pub fn into_owned(self) -> GenericImageOwned

Convert into an owned GenericImageOwned, copying the samples when this is the borrowed half.

Source

impl GenericImage<'_>

pub fn optimum_exposure( &mut self, eval: &OptimumExposure, bin: u16, ) -> Result<OptimumExposureResult, ExposureError>

Optimum exposure and binning, using this image’s own recorded exposure.

Errors

ExposureError::ZeroExposure if the recorded exposure is Duration::ZERO, otherwise see ExposureError.